@@ -104,10 +104,9 @@ impl<T, D> type_object::PySizedLayout<PyArray<T, D>> for npyffi::PyArrayObject {
 
 pyobject_native_type_info!(
     PyArray<T, D>,
-    npyffi::PyArrayObject,
     *npyffi::PY_ARRAY_API.get_type_object(npyffi::NpyTypes::PyArray_Type),
     Some("numpy"),
-    npyffi::PyArray_Check
+    #checkfunction=npyffi::PyArray_Check
     ; T
     ; D
 );
@@ -416,14 +415,15 @@ impl<T: Element, D: Dimension> PyArray<T, D> {
         py: Python<'py>,
         dims: ID,
         strides: *const npy_intp,
-        slice: Box<[T]>,
+        boxed_slice: Box<[T]>,
+        data_ptr: Option<*const T>,
     ) -> &'py Self
     where
         ID: IntoDimension<Dim = D>,
     {
         let dims = dims.into_dimension();
-        let container = SliceBox::new(slice);
-        let data_ptr = container.data;
+        let container = SliceBox::new(boxed_slice);
+        let data_ptr = data_ptr.unwrap_or_else(|| container.data.as_ptr());
         let cell = pyo3::PyClassInitializer::from(container)
             .create_cell(py)
             .expect("Object creation failed.");
@@ -1074,20 +1074,25 @@ impl<T: Element + AsPrimitive<f64>> PyArray<T, Ix1> {
     }
 }
 
-#[test]
-fn test_get_unchecked() {
-    pyo3::Python::with_gil(|py| {
-        let array = PyArray::from_slice(py, &[1i32, 2, 3]);
-        unsafe {
-            assert_eq!(*array.uget([1]), 2);
-        }
-    })
-}
+#[cfg(test)]
+mod tests {
+    use super::PyArray;
 
-#[test]
-fn test_dyn_to_owned_array() {
-    pyo3::Python::with_gil(|py| {
-        let array = PyArray::from_vec2(py, &[vec![1, 2], vec![3, 4]]).unwrap();
-        array.to_dyn().to_owned_array();
-    })
+    #[test]
+    fn test_get_unchecked() {
+        pyo3::Python::with_gil(|py| {
+            let array = PyArray::from_slice(py, &[1i32, 2, 3]);
+            unsafe {
+                assert_eq!(*array.uget([1]), 2);
+            }
+        })
+    }
+
+    #[test]
+    fn test_dyn_to_owned_array() {
+        pyo3::Python::with_gil(|py| {
+            let array = PyArray::from_vec2(py, &[vec![1, 2], vec![3, 4]]).unwrap();
+            array.to_dyn().to_owned_array();
+        })
+    }
 }
